@@ -529,12 +529,20 @@ private:
     //* get widget parent
     QWidget *getParent(const QWidget *widget, int level) const;
 
+    qreal scrollBarTransientAnimationOpacity(const QStyleOption *option, const QWidget *widget) const;
+
     //*@name scrollbar button types (for addLine and subLine )
     //@{
     ScrollBarButtonType _addLineButtons = SingleButton;
     ScrollBarButtonType _subLineButtons = SingleButton;
     //@}
 
+    //*@name scrollbar transient
+    //@{
+    bool _transientScrollBar = false;
+    bool _transientScrollBarAlwaysShowSlim = false;
+    //@}
+
     //* helper
     Helper *_helper = nullptr;
 
